'use strict';

var Backbone = require('backbone');
var jQuery = require('jquery');
var _ = require('underscore');

var router = require('./commons/license-manager.router.js');
var TranslationService = require('./translation/translation.service.js');
var LicenceManagerService = require('./commons/license-manager.service.js');
var errorTemplate = require('./error/error.html');

function getTranslations() {
    var currentLocale = TranslationService.polyglot.locale();
    var translations = TranslationService.polyglot;
    return {
        documentation: translations.t(currentLocale + '.index.documentation'),
        helpdesk: translations.t(currentLocale + '.index.helpdesk'),
        proxyMessage: translations.t(currentLocale + '.index.proxyMessage'),
    };
}

function init() {
    if (window.locale) {
        TranslationService.setLocale(window.locale);
    }

    Backbone.history.start();

    var currentRoute = Backbone.history.getFragment();
    // check status only if we are on index page
    if (currentRoute == '') {
        LicenceManagerService.getStartingState(
            function (startingState) {
                var step = router.routesId[startingState.step];
                router.navigate(step, {trigger: true});
            }, function (err) {
                var template;
                var viewContents = {};
                viewContents.additionalMessage = '';
                template = _.template(errorTemplate);
                viewContents.errorMessage = JSON.parse(err.responseText);
                viewContents.documentation = getTranslations().documentation;
                if (err.status === 409) {
                    viewContents.additionalMessage = getTranslations().helpdesk;
                }
                if (err.status === 404) {
                    viewContents.additionalMessage = getTranslations().proxyMessage;
                }
                jQuery('#license-manager').html(template(viewContents));
            }
        );
    }
}

jQuery(document).ready(function() {
    init();
});
