var Backbone = require('backbone');
var jQuery = require('jquery');
var _ = require('underscore');

var LicenceManagerService = require('../commons/license-manager.service.js');
var TranslationService = require('../translation/translation.service.js');
var errorTemplate = require('../error/error.html');
var loginTemplate = require('./login.html');

var LoginForm = Backbone.View.extend({
    className: 'login-subview',

    el: '#license-manager',

    events: {
        'submit #login-form': 'login'
    },

    initialize: function() {
        this.template = _.template(loginTemplate);
    },

    render: function() {
        var viewContents = _.extend(
            {},
            this.getTranslations(),
            this.getViewData()
        );
        this.$el.html(this.template(viewContents));
        return this;
    },

    getTranslations: function() {
        var currentLocale = TranslationService.polyglot.locale();
        var translations = TranslationService.polyglot;
        return {
            introMessage: translations.t(currentLocale + '.login.introMessage'),
            email: translations.t(currentLocale + '.login.email'),
            password: translations.t(currentLocale + '.login.password'),
            connect: translations.t(currentLocale + '.login.connect'),
            errorMessage: translations.t(currentLocale + '.login.errorMessage'),
            proxyMessage: translations.t(currentLocale + '.login.proxyMessage'),
            documentation: translations.t(currentLocale + '.login.documentation'),
            subscriptionText: translations.t(currentLocale + '.login.subscriptionText'),
            subscription: translations.t(currentLocale + '.login.subscription'),
            subscriptionUrl: translations.t(currentLocale + '.login.subscriptionUrl')
        };
    },

    getViewData: function() {
        return {
            subscriptionLink: '#'
        };
    },

    login: function(e) {
        e.preventDefault();
        var login = this.$el.find('*[name="email"]').val();
        var password = this.$el.find('*[name="password"]').val();
        var errorContainer = this.$el.find('.error-msg')[0];
        var self = this;
        var viewContents = {};

        LicenceManagerService.login(
            login,
            password,
            function () {
                var router = require('../commons/license-manager.router.js');
                router.navigate('subscribe', {trigger: true});
            },
            function (err) {
                jQuery(errorContainer).find('span').text(JSON.parse(err.responseText));
                jQuery(errorContainer).removeClass('hidden');
                if (err.status == '409') {
                    var router = require('../commons/license-manager.router.js');
                    router.navigate('subscribe', {trigger: true});
                    jQuery(errorContainer).find('span').text(JSON.parse(err.responseText));
                } else if (err.status == '404') {
                    jQuery(errorContainer).find('span').append(' ' + self.getTranslations().proxyMessage + self.getTranslations().documentation);
                }
                self.$el.html(self.template(viewContents));
            }
        );
    }
});

module.exports = LoginForm;
